/**
 * Copyright (c) Samuel Wall.
 *
 * This source code is licensed under the MIT license found in the
 * license file in the root directory of this source tree.
 */
import React, { useEffect, useState } from 'react';
import mermaid from 'mermaid';
import { getTheme } from './theme.helper.js';
/**
 * Assign a unique ID to each mermaid svg as per requirements
 * of `mermaid.render`.
 */
let id = 0;
/**
 * Component to display Mermaid diagrams.
 *
 * @param param0 Diagram to display.
 * @param param1 Config.
 * @returns The component.
 */
export const Mermaid = ({ chart, config }) => {
    // Due to Docusaurus not correctly parsing client-side from server-side modules, use the provided workaround
    // found in the accompanying issue: https://github.com/facebook/docusaurus/issues/4268#issuecomment-783553084
    /* istanbul ignore next */
    if (typeof window === 'undefined') {
        return React.createElement("div", null);
    }
    const html = document.querySelector('html');
    // Watch for changes in theme in the HTML attribute `data-theme`.
    const [theme, setTheme] = useState(getTheme(html, config));
    useEffect(() => {
        const observer = new MutationObserver((mutations) => {
            for (const mutation of mutations) {
                if (mutation.type !== 'attributes' || mutation.attributeName !== 'data-theme') {
                    continue;
                }
                setTheme(getTheme(mutation.target, config));
                break;
            }
        });
        observer.observe(html, { attributes: true });
        return () => {
            try {
                observer.disconnect();
            }
            catch {
                // Do nothing
            }
        };
    }, [chart, config, theme]);
    // When theme updates, rerender the SVG.
    const [svg, setSvg] = useState('');
    useEffect(() => {
        const render = () => {
            mermaid.render(`mermaid-svg-${id.toString()}`, chart, (renderedSvg) => setSvg(renderedSvg));
            id++;
        };
        if (config) {
            if (config.mermaid) {
                mermaid.initialize({ startOnLoad: true, ...config.mermaid, theme });
            }
            else {
                mermaid.initialize({ startOnLoad: true, theme });
            }
            render();
        }
        else {
            // Is there a better way?
            setTimeout(render, 0);
        }
    }, [theme, chart]);
    return React.createElement("div", { dangerouslySetInnerHTML: { __html: svg } });
};
//# sourceMappingURL=Mermaid.js.map